Authorization Group Creation
==================================

To simplify the management of topic restrictions, related topics are assembled into "topic groups" . For example, the
topics exposed by the McAfee Threat Intelligence (TIE) service that can be invoked by any client (unrestricted) are
grouped into the "TIE Server Service Operations" group (see image below).

The following section walks through the steps to create a new DXL topic authorization group. In this particular
example we are creating a group for the topics that will be exposed by a new DXL service.

#. Navigate to **Server Settings** and select the **DXL Topic Authorization** setting on the left navigation bar.

    .. image:: addtopicgroup1.png

#. Click the **Edit** button in the lower right corner (as shown in the image above)

    .. image:: addtopicgroup2.png

#. Click the **Actions** button and select **Add Topic Group** (as shown in the image above)

    .. image:: addtopicgroup3.png

#. Enter in a **Group Name** and a topic to associate with that **Group Name**

    .. image:: addtopicgroup4.png

#. If more than one topic needs to be associated with the **Group Name** click the **+** button to add more rows for **Topics**

    .. image:: addtopicgroup5.png

#. Click the **OK** button in the lower right corner (as shown in the image above)

    .. image:: addtopicgroup6.png

#. Click the **Save** button in the lower right corner (as shown in the image above)